pub struct WatcherGetCrashEventResponse {
pub event: EventPair,
}Fields
event: EventPairTrait Implementations
Sourceimpl Debug for WatcherGetCrashEventResponse
impl Debug for WatcherGetCrashEventResponse
Sourceimpl Decode<WatcherGetCrashEventResponse, DefaultFuchsiaResourceDialect> for WatcherGetCrashEventResponse
impl Decode<WatcherGetCrashEventResponse, DefaultFuchsiaResourceDialect> for WatcherGetCrashEventResponse
Sourceimpl Encode<WatcherGetCrashEventResponse, DefaultFuchsiaResourceDialect> for &mut WatcherGetCrashEventResponse
impl Encode<WatcherGetCrashEventResponse, DefaultFuchsiaResourceDialect> for &mut WatcherGetCrashEventResponse
Sourceimpl<T0: Encode<HandleType<EventPair, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<WatcherGetCrashEventResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<HandleType<EventPair, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<WatcherGetCrashEventResponse, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Hash for WatcherGetCrashEventResponse
impl Hash for WatcherGetCrashEventResponse
Sourceimpl Ord for WatcherGetCrashEventResponse
impl Ord for WatcherGetCrashEventResponse
Sourcefn cmp(&self, other: &WatcherGetCrashEventResponse) -> Ordering
fn cmp(&self, other: &WatcherGetCrashEventResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WatcherGetCrashEventResponse
impl PartialEq for WatcherGetCrashEventResponse
Sourcefn eq(&self, other: &WatcherGetCrashEventResponse) -> bool
fn eq(&self, other: &WatcherGetCrashEventResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WatcherGetCrashEventResponse
impl PartialOrd for WatcherGetCrashEventResponse
Sourceimpl ResourceTypeMarker for WatcherGetCrashEventResponse
impl ResourceTypeMarker for WatcherGetCrashEventResponse
Sourcetype Borrowed<'a> = &'a mut WatcherGetCrashEventResponse
type Borrowed<'a> = &'a mut WatcherGetCrashEventResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for WatcherGetCrashEventResponse
impl TypeMarker for WatcherGetCrashEventResponse
Sourcetype Owned = WatcherGetCrashEventResponse
type Owned = WatcherGetCrashEventResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for WatcherGetCrashEventResponse
impl Standalone<DefaultFuchsiaResourceDialect> for WatcherGetCrashEventResponse
impl StructuralPartialEq for WatcherGetCrashEventResponse