pub struct Crash {
pub subsystem_name: Option<String>,
pub timestamp: Option<BootInstant>,
pub reason: Option<String>,
pub count: Option<u32>,
pub firmware_version: Option<String>,
pub crash_dump: Option<Vmo>,
/* private fields */
}Fields
subsystem_name: Option<String>Name or identifier for the subsystem which crashed.
timestamp: Option<BootInstant>Approximate timestamp when the crash occurred.
reason: Option<String>The description or code indicating why the crash occurred.
count: Option<u32>The number of times this subsystem has crashed. Note that this is ignored if supplied by in Reporter.Report and instead aggregated by the protocol implementer based on subsystem_name.
firmware_version: Option<String>Optional version of the subsystem’s firmware.
crash_dump: Option<Vmo>Optional dump of the subsystem’s failure. Not available on user builds.